@@ -547,6 +547,52 @@ class _SdcCommon(object):
 
         return True, res.content
 
+    def delete_sysdig_capture(self, capture_id):
+        """
+        Removes an existing Sysdig Capture from Monitor
+
+        Args:
+            capture_id: ID of the capture to remove
+
+        Returns: A touple of (bool, error) where the first value is false if there's an error and the second value is the error.
+        """
+
+        res = self.http.delete(f'{self.url}/api/sysdig/{capture_id}', headers=self.hdrs, verify=self.ssl_verify)
+
+        if not self._checkResponse(res):
+            return False, self.lasterr
+
+        return True, None
+
+    def create_user(self, user_email, first_name=None, last_name=None, password=None):
+        '''
+        Provisions a new user to use Sysdig without sending an email notification.
+        If password is not set through this request a random one is generated for the user
+        which requires them to reset password on first login.
+
+        Args:
+            user_email (str): Email of the user to provision.
+            first_name (str): First name of the user to provision. Can be null.
+            last_name (str): Last name of the user to provision. Can be null.
+            password (str): Default password for the user to provision. If this is not set, a random one is generated.
+
+        Returns:
+            The provisioned user information.
+
+        '''
+
+        user_info = {
+            "username": user_email,
+            "firstName": first_name,
+            "lastName": last_name,
+            "password": password,
+        }
+        user_info = {k: v for k, v in user_info.items() if v}
+
+        res = self.http.post(self.url + '/api/user/provisioning/', headers=self.hdrs, data=json.dumps(user_info),
+                             verify=self.ssl_verify)
+        return self._request_result(res)
+
     def create_user_invite(self, user_email, first_name=None, last_name=None, system_role=None):
         '''**Description**
             Invites a new user to use Sysdig Monitor. This should result in an email notification to the specified address.
